health

package
v0.0.0-...-79153e9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2017 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func StartHealthMonitor

func StartHealthMonitor(rec slf.StatsReporter)

StartHealthMonitor starts goroutine, that will poll memory stats and send them as metrics every second

Common usage: StartHealthMonitor(wd.New("", "app.").WithParams(util.HostParam()))

func StartLogToMetrics

func StartLogToMetrics(rec slf.StatsReporter)

StartLogToMetrics registers and binds special events receiver, that counts log messages per-level and sends counters as metrics events

Common usage: StartLogToMetrics(wd.New("", "log.").WithParams(util.HostParam()))

Types

This section is empty.

Jump to