mutators

package
v0.0.0-...-79153e9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2017 License: MIT Imports: 2 Imported by: 0

README

Mutators are components, that takes an event and changes it's contents

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AddInstanceIDToLog

type AddInstanceIDToLog struct{}

AddInstanceIDToLog mutator injects global InstanceID to all log packets

func (AddInstanceIDToLog) Modify

func (a AddInstanceIDToLog) Modify(e *slf.Event)

Modify injects instance ID to logs only

type HideInfo

type HideInfo struct {
	Predicate func(slf.Event) bool
}

HideInfo is mutator, that converts INFO log levels to DEBUG

func HideInfoForMarker

func HideInfoForMarker(markerName string) HideInfo

HideInfoForMarker builds HideInfo mutator, than works only with log events, marked with particular marker

func (HideInfo) Modify

func (h HideInfo) Modify(e *slf.Event)

Modify changes log level from INFO to DEBUG

Jump to