recievers

package
v0.0.0-...-79153e9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2017 License: MIT Imports: 5 Imported by: 0

README

This package contains receivers, that can handle incoming log messages

  • ansi - Colored console output
  • logstash - Logstash client
  • statsd - StatsD client
  • sentry - Sentry client

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewMetricsBuffer

func NewMetricsBuffer(flushInterval time.Duration, flushTo func([]slf.Event)) slf.Receiver

NewMetricsBuffer builds new metrics buffer for desired flush interval

Types

This section is empty.

Directories

Path Synopsis

Jump to