Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartHealthMonitor ¶
func StartHealthMonitor(rec slf.StatsReporter)
StartHealthMonitor starts goroutine, that will poll memory stats and send them as metrics every second
Common usage: StartHealthMonitor(wd.New("", "app.").WithParams(util.HostParam()))
func StartLogToMetrics ¶
func StartLogToMetrics(rec slf.StatsReporter)
StartLogToMetrics registers and binds special events receiver, that counts log messages per-level and sends counters as metrics events
Common usage: StartLogToMetrics(wd.New("", "log.").WithParams(util.HostParam()))
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.